# simplebuild
A very simple to use build system for projects with primarily C++/Python code, intended for usage by scientific developers without a strong SW-engineering background.

## Installation via pip [![PyPI](https://img.shields.io/pypi/v/simple-build-system.svg)](https://pypi.org/project/simple-build-system)
Simplebuild is distributed via PyPI  with the package name `simple-build-system` and can be installed via:
```
  python3 -mpip install -U simple-build-system
```

## Installation via conda
A dedicated conda package is planned but not yet ready.
